///////////////////////////////////////////////////////////////////////////////
//
// IFCanpf_h
//
// Declare function prototypes and structures and symbols exported from the pcicanpf.dll
//
// Copyright 2003 Interface Corporation. All rights reserved.
//
///////////////////////////////////////////////////////////////////////////////
#if !defined( _IFCAN_H_ )
#include "ifcan.h"
#endif

#if !defined( _IFCANPF_H_ )
#define _IFCANPF_H_

#ifdef __cplusplus
extern "C" {
#endif

//-----------------------------------------------------------------------------------------------
//		structure
//-----------------------------------------------------------------------------------------------
typedef struct {
	ULONG ulStartBit;
	ULONG ulBitCount;
	ULONG ulByteOrder;
	ULONG ulDataType;
} CAN_PROFILE_DATA, *PCAN_PROFILE_DATA;

//-----------------------------------------------------------------------------------------------
//		error code
//-----------------------------------------------------------------------------------------------
#define IFCAN_ERROR_PROFILE_NOT_FOUND				0xC0004001
#define IFCAN_ERROR_PROFILE_DATATYPE_MISMATCH		0xC0004002
#define IFCAN_ERROR_PROFILE_ITEM_NOT_FOUND			0xC0004003
#define IFCAN_ERROR_PROFILE_ALREADY_EXISTS			0xC0004004
#define IFCAN_ERROR_PROFILE_OVERFLOW				0xC0004005
#define IFCAN_ERROR_INVALID_FILE_FORMAT				0xC0004006
#define IFCAN_ERROR_CANT_ACCESS_FILE				0xC0004007

//-----------------------------------------------------------------------------------------------
//		identifiers
//-----------------------------------------------------------------------------------------------
#define CAN_BYTEORDER_INTEL			1
#define CAN_BYTEORDER_MOTOROLA		2

#define CAN_DATATYPE_INTEGER8		0x001
#define CAN_DATATYPE_INTEGER16		0x002
#define CAN_DATATYPE_INTEGER32		0x003
#define CAN_DATATYPE_INTEGER64		0x004
#define CAN_DATATYPE_FLOAT			0x010
#define CAN_DATATYPE_FLOAT64		0x020
#define CAN_DATATYPE_STRING			0x100
#define CAN_DATATYPE_INTEGER		0x00F

#define CAN_ANY_NUMBER				 -1
#define CAN_MAX_PROFILE				16384
#define CAN_MAX_PROFILE_NAME		64
#define CAN_MAX_PROFILE_ITEMS		64
#define CAN_MAX_PROFILE_ID			0x1FFFFFFF

//-----------------------------------------------------------------------------------------------
//		function prototypes
//-----------------------------------------------------------------------------------------------
#define DLLEXPORT __declspec(dllexport)

#ifndef SimCAN
DLLEXPORT int WINAPI CanQueryProfile(PCAN_MESSAGE, int *);
DLLEXPORT int WINAPI CanApplyProfile(PCAN_MESSAGE, void *, int, int *);
DLLEXPORT int WINAPI CanApplyProfileInteger(PCAN_MESSAGE, int *, int);
DLLEXPORT int WINAPI CanApplyProfileFloat(PCAN_MESSAGE, float *, int);
DLLEXPORT int WINAPI CanApplyProfileDouble(PCAN_MESSAGE, double *, int);
DLLEXPORT int WINAPI CanSetProfile(int *, char *, unsigned long, int, PCAN_PROFILE_DATA);
DLLEXPORT int WINAPI CanGetProfile(int, char *, unsigned long *, int *, PCAN_PROFILE_DATA);
DLLEXPORT int WINAPI CanDeleteProfile(int);
DLLEXPORT int WINAPI CanLoadProfile(LPCTSTR);
DLLEXPORT int WINAPI CanSaveProfile(LPCTSTR);
#endif

#ifdef __cplusplus
}
#endif

#endif

