///////////////////////////////////////////////////////////////////////////////
//
// IFCan_H
//
// Declare function prototypes and structures and symbols exported from the IFCAN.DLL.
//
// Copyright 2003 Interface Corporation. All rights reserved.
//
///////////////////////////////////////////////////////////////////////////////
#if !defined( _IFCAN_H_ )
#define _IFCAN_H_

#ifdef __cplusplus
extern "C" {
#endif

typedef void (CALLBACK* CANCALLBACK)(DWORD dwFactor, DWORD dwUser);
typedef CANCALLBACK	FAR LPCANCALLBACK;


// -----------------------------------------------------------------------
//	Symbols and/or identifiers
// -----------------------------------------------------------------------

// EventMask
#define CAN_EVENT_TRANSCEIVER_ERROR	0x00001000
#define CAN_EVENT_ERR_FIFO_OVER		0x00000200
#define CAN_EVENT_DETECT_OVERRUN	0x00000100
#define CAN_EVENT_CYCLIC_SEND_STOP	0x00000080
#define CAN_EVENT_BUS_STATUS		0x00000040
#define CAN_EVENT_RECV				0x00000020
#define CAN_EVENT_ERROR				0x00000010
#define CAN_EVENT_TXB_IS_EMPTY		0x00000008
#define CAN_EVENT_ERROR_LIMIT		0x00000004
#define CAN_EVENT_RXB_FULL			0x00000002
#define CAN_EVENT_ERB_FULL			0x00000001

// ClearFlag
#define CAN_CLEAR_TXB				0x00000020
#define CAN_CLEAR_RXB				0x00000010
#define CAN_CLEAR_TXERR				0x00000008
#define CAN_CLEAR_RXERR				0x00000004
#define CAN_CLEAR_ERB				0x00000002
#define CAN_CLEAR_TIMERCOUNTER		0x00000001

// ulLineMode (Port Config Structure)
#define CAN_NORMAL_MODE				0
#define CAN_LISTEN_ONLY_MODE		1
#define CAN_FIFO_SEND_MODE			0x80000000

// ulFilterMode (Port Config Structure)	
#define CAN_DUAL_FILTER				0
#define CAN_SINGLE_FILTER			1

// ulBaudRate (Port Config Structure)
#define	CAN_BAUDRATE_33_3k			0x00002724
#define	CAN_BAUDRATE_50k			0x00001D23
#define	CAN_BAUDRATE_83_3k			0x00000F24
#define	CAN_BAUDRATE_95_2k			0x00000D24
#define	CAN_BAUDRATE_100k			0x00000936
#define	CAN_BAUDRATE_125k			0x0000053A
#define	CAN_BAUDRATE_250k			0x0000023A
#define	CAN_BAUDRATE_500k			0x00000127
#define	CAN_BAUDRATE_1M				0x00000027
#define CAN_BAUDRATE_BTR			0x80000000

// ulBusStatus (Port Status Structure)
#define CAN_BUS_OFF					0x00000004
#define	CAN_BUS_PASSIVE				0x00000002
#define CAN_BUS_ACTIVE				0x00000001

// ulID (CAN Message Structure)
#define CAN_EXT_FRAME				0x80000000

// ulFlag (CAN Message Structure)
#define CAN_MSG_RTR					1

// ulInterruptRegister (Error Information Structure)
#define CAN_DETECT_BUS_ERROR		0x00000080
#define CAN_DETECT_ARBITRATION_LOST	0x00000040
#define CAN_IS_ERROR_PASSIVE		0x00000020
#define CAN_DETECT_OVERRUN			0x00000008
#define CAN_IS_ERROR_WARNING		0x00000004

// Kind of FIFO
#define CAN_RECEIVE_FIFO			0
#define CAN_ERROR_FIFO				1
#define CAN_SEND_FIFO				2

// FIFO-Trigger
#define CAN_TRIGGER_1				0
#define CAN_TRIGGER_16				1
#define CAN_TRIGGER_32				2
#define CAN_TRIGGER_48				3

// Physical layer
#define CAN_PHYSICALLAYER_LOWSPEED	0
#define CAN_PHYSICALLAYER_HIGHSPEED	1

// -----------------------------------------------------------------------
//	Return Value
// -----------------------------------------------------------------------
#define IFCAN_ERROR_SUCCESS					0			// The process was successfully comoeted.
#define IFCAN_ERROR_NOT_READY				0xC0000001	// The current driver cannot be used.
#define IFCAN_ERROR_ACCESS_DENIED			0xC0000002	// The current device is deleted.
#define IFCAN_ERROR_INVALID_PARAMETER		0xC0000003	// Invalid parameter is specified.
#define IFCAN_ERROR_INSUFFICIENT_BUFFER		0xC0000004	// The data area passed to the 
#define IFCAN_ERROR_NOT_OPEN				0xC0000005	// The port tried to close before opening the port.
#define IFCAN_ERROR_MEMORY_NOTALLOCATED		0xC0000006	// Not enough memory.
#define IFCAN_ERROR_BUFFER_IS_FULL			0xC0000007	// The buffer is full.
#define IFCAN_ERROR_BUFFER_IS_EMPTY			0xC0000008	// The buffer is empty.
#define IFCAN_ERROR_CANNOT_ACCESS			0xC0000009	// Invlalid function is specified. 
                                                                        // The buffer of cycle transmission data is forwarding.
#define IFCAN_ERROR_INVALID_HANDLE			0xC000000A	// The device handle is invalid.
#define IFCAN_ERROR_NOT_SUPPORTED			0xC000000B	// The specified capability is not supported.
#define IFCAN_ERROR_NOW_SENDING				0xC000000C	// It is cycle or data transmission now.

// -----------------------------------------------------------------------
//	Port Config Structure
// -----------------------------------------------------------------------
typedef struct{
	ULONG	ulLineMode;
	ULONG	ulFilterMode;
	ULONG	ulTXBSize;
	ULONG	ulRXBSize;
	ULONG	ulERBSize;
	ULONG	ulErrorLimit;
	ULONG	ulBaudRate;
} CAN_PORT_CONFIG, *PCAN_PORT_CONFIG;

// -----------------------------------------------------------------------
//	Port Status Structure
// -----------------------------------------------------------------------
typedef struct{
	ULONG	ulBusStatus;
	ULONG	ulTXBCount;
	ULONG	ulRXBCount;
	ULONG	ulERBCount;
	ULONG	ulTXERRCount;
	ULONG	ulRXERRCount;
} CAN_PORT_STATUS, *PCAN_PORT_STATUS;

// -----------------------------------------------------------------------
//	CAN Message Structure
// -----------------------------------------------------------------------
typedef struct{
	ULONG	ulLength;
	ULONG	ulFlag;
	ULONG	ulID;
	BYTE	bData[8];
	ULONG	ulTime;
} CAN_MESSAGE, *PCAN_MESSAGE;

// -----------------------------------------------------------------------
//	Error Information Structure
// -----------------------------------------------------------------------
typedef struct{
	ULONG	ulInterruptRegister;
	ULONG	ulErrorCodeRegister;
	ULONG	ulArbitrationLostRegister;
	ULONG	ulTime;
} CAN_ERROR, *PCAN_ERROR;

// -----------------------------------------------------------------------
//	Event Request Structure
// -----------------------------------------------------------------------
typedef struct {
	HWND			hWnd;
	HANDLE			hInterruptEvent;
	LPCANCALLBACK	lpCallBackProc;
	UINT			uInterruptMsg;
	DWORD			dwUser;
} CAN_EVENT_REQ, *PCAN_EVENT_REQ;

// -----------------------------------------------------------------------
//	Port Information Structure
// -----------------------------------------------------------------------
typedef struct {
	ULONG	ulStructLength;
	ULONG	ulVendorID;
	ULONG	ulDeviceID;
	ULONG	ulSubsystemID;
	ULONG	ulRevisionID;
	ULONG	ulBoardID;
	ULONG	ulModelNumber;
	ULONG	ulChannelNumber;
	ULONG	ulPhysicalLayer;
} CAN_PORT_INFORMATION, *PCAN_PORT_INFORMATION;

// -----------------------------------------------------------------------
//	Function Prototype
// -----------------------------------------------------------------------
#if !defined(_IFCANLIB_)
#define IFCANAPI
#else
#define IFCANAPI __declspec(dllexport)
#endif

#ifndef SimCAN
IFCANAPI HANDLE WINAPI	CanOpenPort( LPCTSTR lpszName );
IFCANAPI INT WINAPI	CanClosePort( HANDLE hDeviceHandle );
IFCANAPI INT WINAPI	CanSetConfig( HANDLE hDeviceHandle, PCAN_PORT_CONFIG pPortConfig );
IFCANAPI INT WINAPI	CanGetConfig( HANDLE hDeviceHandle, PCAN_PORT_CONFIG pPortConfig );
IFCANAPI INT WINAPI	CanActivate( HANDLE hDeviceHandle );
IFCANAPI INT WINAPI	CanDeactivate( HANDLE hDeviceHandle );
IFCANAPI INT WINAPI	CanGetStatus( HANDLE hDeviceHandle, PCAN_PORT_STATUS pPortStatus);
IFCANAPI INT WINAPI	CanSendMessage( HANDLE hDeviceHandle, PCAN_MESSAGE pCanMessage, unsigned long ulCount );
IFCANAPI INT WINAPI	CanReceiveMessage( HANDLE hDeviceHandle, PCAN_MESSAGE pCanMessage, unsigned long* pulCount );
IFCANAPI INT WINAPI	CanGetErrorEvent( HANDLE hDeviceHandle, PCAN_ERROR pCanError, unsigned long* pulCount );
IFCANAPI INT WINAPI	CanSetEvent( HANDLE hDeviceHandle, PCAN_EVENT_REQ pEvent );
IFCANAPI INT WINAPI	CanKillEvent( HANDLE hDeviceHandle );
IFCANAPI INT WINAPI	CanSetEventMask( HANDLE hDeviceHandle, DWORD dwEventMask );
IFCANAPI INT WINAPI	CanGetEventMask( HANDLE hDeviceHandle, PDWORD pdwEventMask );
IFCANAPI INT WINAPI	CanSetAcceptanceFilter( HANDLE  hDeviceHandle, DWORD dwAcceptanceCode, DWORD dwAcceptanceMask );
IFCANAPI INT WINAPI	CanGetAcceptanceFilter( HANDLE  hDeviceHandle, PDWORD pdwAcceptanceCode, PDWORD pdwAcceptanceMask );
IFCANAPI INT WINAPI	CanClearBuffer( HANDLE  hDeviceHandle, DWORD dwClearBuffer );

IFCANAPI INT WINAPI	CanSetFifoTrigger( HANDLE  hDeviceHandle, DWORD dwFifoKind, DWORD dwTriggerValue, DWORD dwFifoTimeout );
IFCANAPI INT WINAPI	CanGetFifoTrigger( HANDLE  hDeviceHandle, DWORD dwFifoKind, PDWORD pdwTriggerValue, PDWORD pdwFifoTimeout );
IFCANAPI INT WINAPI	CanCyclicSendMessage( HANDLE  hDeviceHandle, PCAN_MESSAGE pCanMessage );
IFCANAPI INT WINAPI	CanStopCyclicSendMessage( HANDLE  hDeviceHandle );
IFCANAPI INT WINAPI	CanGetCompletionMessage( HANDLE  hDeviceHandle, PCAN_MESSAGE pCanMessage, unsigned long* pulCount);
IFCANAPI INT WINAPI	CanGetPortInformation(HANDLE hDeviceHandle, PCAN_PORT_INFORMATION pInfo);
#endif

#ifdef __cplusplus
}
#endif

#endif

//.IFCAN.H
